@@ -64,7 +64,7 @@ int main(int argc, char *argv[])
                      applicationDescription,
                      KAboutLicense::LGPL_V2_1,
                      i18n("© 2020 KDE Community"));
-    about.addAuthor("Plata", QString(), QStringLiteral("plata.hill@kdemail.net"));
+    about.addAuthor(QStringLiteral("Plata"), QString(), QStringLiteral("plata.hill@kdemail.net"));
     KAboutData::setApplicationData(about);
 
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.telly-skout")));
